@@ -1,14 +1,11 @@
-import json
 import datetime
-import requests
 
 from collections import defaultdict
-from functools import wraps
-from flask import request, current_app, render_template, redirect, abort
+from flask import request, render_template
 
-from alerta.app import app, db, status_code
+from alerta.app import app, db
 from alerta.app.switch import Switch
-from alerta.app.utils import parse_fields, crossdomain
+from alerta.app.utils import jsonify, jsonp, auth_required, parse_fields, crossdomain
 from alerta.app.metrics import Timer
 from alerta.alert import Alert
 from alerta.heartbeat import Heartbeat
@@ -20,7 +17,6 @@ LOG = app.logger
 def setup():
     global plugins
     plugins = load_plugins()
-    LOG.debug('Loaded plug-ins: %s', plugins)
 
 
 # Set-up metrics
@@ -35,133 +31,6 @@ tag_timer = Timer('alerts', 'tagged', 'Tagging alerts', 'Total time to tag numbe
 untag_timer = Timer('alerts', 'untagged', 'Removing tags from alerts', 'Total time to un-tag number of alerts')
 
 
-class DateEncoder(json.JSONEncoder):
-    def default(self, obj):
-
-        if isinstance(obj, (datetime.date, datetime.datetime)):
-            return obj.replace(microsecond=0).strftime('%Y-%m-%dT%H:%M:%S') + ".%03dZ" % (obj.microsecond // 1000)
-        else:
-            return json.JSONEncoder.default(self, obj)
-
-
-# Over-ride jsonify to support Date Encoding
-def jsonify(*args, **kwargs):
-    return current_app.response_class(json.dumps(dict(*args, **kwargs), cls=DateEncoder,
-                                                 indent=None if request.is_xhr else 2), mimetype='application/json')
-
-
-def authenticate():
-
-    return jsonify(status="error", message="authentication required"), 401
-
-
-def verify_token(token):
-
-    if db.is_token_valid(token):
-        return True
-
-    url = 'https://www.googleapis.com/oauth2/v1/tokeninfo?access_token=' + token
-    response = requests.get(url)
-    token_info = response.json()
-    LOG.debug('Token info %s', json.dumps(token_info))
-
-    if 'error' in token_info:
-        LOG.warning('Token authentication failed: %s', token_info['error'])
-        return False
-
-    if 'audience' in token_info:
-        if token_info['audience'] != app.config['OAUTH2_CLIENT_ID']:
-            LOG.warning('Token supplied was for different web application')
-            return False
-
-    if 'email' in token_info:
-        if not ('*' in app.config['ALLOWED_EMAIL_DOMAINS']
-                or token_info['email'].split('@')[1] in app.config['ALLOWED_EMAIL_DOMAINS']
-                or db.is_user_valid(token_info['email'])):
-            LOG.info('User %s not authorized to access API', token_info['email'])
-            return False
-    else:
-        LOG.warning('No email address present in token info')
-        return False
-
-    db.save_token(token)
-    return True
-
-
-def verify_api_key(key):
-
-    LOG.debug('we got a api key %s, verify key internally', key)
-
-    if not db.is_key_valid(key):
-        return False
-
-    db.update_key(key)
-    return True
-
-
-def get_user_info(token):
-
-    url = 'https://www.googleapis.com/oauth2/v1/userinfo?access_token=' + token
-    response = requests.get(url)
-    user_info = response.json()
-    LOG.debug('User info %s', json.dumps(user_info))
-
-    if 'error' in user_info:
-        LOG.warning('Token authentication failed: %s', user_info['error'])
-        return None
-
-    return user_info
-
-
-def auth_required(func):
-    @wraps(func)
-    def decorated(*args, **kwargs):
-
-        if not app.config['AUTH_REQUIRED']:
-            return func(*args, **kwargs)
-
-        if 'Authorization' in request.headers:
-            auth = request.headers['Authorization']
-            LOG.debug(auth)
-            if auth.startswith('Token'):
-                token = auth.replace('Token ', '')
-                if not verify_token(token):
-                    return authenticate()
-            elif auth.startswith('Key'):
-                key = auth.replace('Key ', '')
-                if not verify_api_key(key):
-                    return authenticate()
-            else:
-                return authenticate()
-        elif 'token' in request.args:
-            token = request.args['token']
-            if not verify_token(token):
-                return authenticate()
-        elif 'api-key' in request.args:
-            key = request.args['api-key']
-            if not verify_api_key(key):
-                return authenticate()
-        else:
-            return authenticate()
-        return func(*args, **kwargs)
-    return decorated
-
-
-def jsonp(func):
-    """Wraps JSONified output for JSONP requests."""
-    @wraps(func)
-    def decorated(*args, **kwargs):
-        callback = request.args.get('callback', False)
-        if callback:
-            data = str(func(*args, **kwargs).data)
-            content = str(callback) + '(' + data + ')'
-            mimetype = 'application/javascript'
-            return current_app.response_class(content, mimetype=mimetype)
-        else:
-            return func(*args, **kwargs)
-    return decorated
-
-
 @app.route('/_', methods=['OPTIONS', 'PUT', 'POST', 'DELETE', 'GET'])
 @crossdomain(origin='*', headers=['Origin', 'X-Requested-With', 'Content-Type', 'Accept'])
 @jsonp
@@ -314,6 +183,8 @@ def receive_alert():
                 return jsonify(status="error", message=str(e)), 403
             except Exception as e:
                 LOG.warning('Error while running pre-receive plug-in: %s', e)
+            if not incomingAlert:
+                LOG.error('Plug-in pre-receive hook did not return modified alert')
 
     try:
         if db.is_duplicate(incomingAlert):
@@ -494,7 +365,7 @@ def delete_alert(id):
 def get_counts():
 
     try:
-        query, _, _, _, query_time = parse_fields(request)
+        query, _, _, _, _ = parse_fields(request)
     except Exception as e:
         return jsonify(status="error", message=str(e)), 400
 
@@ -531,7 +402,7 @@ def get_counts():
 def get_top10():
 
     try:
-        query, _, group, _, query_time = parse_fields(request)
+        query, _, group, _, _ = parse_fields(request)
     except Exception as e:
         return jsonify(status="error", message=str(e)), 400
 
@@ -565,7 +436,7 @@ def get_top10():
 def get_environments():
 
     try:
-        query, _, _, limit, query_time = parse_fields(request)
+        query, _, _, limit, _ = parse_fields(request)
     except Exception as e:
         return jsonify(status="error", message=str(e)), 400
 
@@ -596,7 +467,7 @@ def get_environments():
 def get_services():
 
     try:
-        query, _, _, limit, query_time = parse_fields(request)
+        query, _, _, limit, _ = parse_fields(request)
     except Exception as e:
         return jsonify(status="error", message=str(e)), 400
 
@@ -619,80 +490,6 @@ def get_services():
             services=[],
         ), 404
 
-@app.route('/pagerduty', methods=['OPTIONS', 'POST'])
-@crossdomain(origin='*', headers=['Origin', 'X-Requested-With', 'Content-Type', 'Accept'])
-def pagerduty():
-
-    if not request.json or not 'messages' in request.json:
-        abort(400)
-
-    for message in request.json['messages']:
-
-        LOG.debug('%s', json.dumps(message))
-
-        id = message['data']['incident']['incident_key']
-        html_url = message['data']['incident']['html_url']
-        incident_number = message['data']['incident']['incident_number']
-        incident_url = '<a href="%s">#%s</a>' % (html_url, incident_number)
-
-        LOG.info('PagerDuty incident #%s webhook for alert %s', incident_number, id)
-
-        LOG.error('previous status %s', db.get_alert(id=id).status)
-
-        if message['type'] == 'incident.trigger':
-            status = status_code.OPEN
-            user = message['data']['incident']['assigned_to_user']['name']
-            text = 'Incident %s assigned to %s' % (incident_url, user)
-        elif message['type'] == 'incident.acknowledge':
-            status = status_code.ACK
-            user = message['data']['incident']['assigned_to_user']['name']
-            text = 'Incident %s acknowledged by %s' % (incident_url, user)
-        elif message['type'] == 'incident.unacknowledge':
-            status = status_code.OPEN
-            text = 'Incident %s unacknowledged due to timeout' % incident_url
-        elif message['type'] == 'incident.resolve':
-            status = status_code.CLOSED
-            if message['data']['incident']['resolved_by_user']:
-                user = message['data']['incident']['resolved_by_user']['name']
-            else:
-                user = 'n/a'
-            text = 'Incident %s resolved by %s' % (incident_url, user)
-        elif message['type'] == 'incident.assign':
-            status = status_code.ASSIGN
-            user = message['data']['incident']['assigned_to_user']['name']
-            text = 'Incident %s manually assigned to %s' % (incident_url, user)
-        elif message['type'] == 'incident.escalate':
-            status = status_code.OPEN
-            user = message['data']['incident']['assigned_to_user']['name']
-            text = 'Incident %s escalated to %s' % (incident_url, user)
-        elif message['type'] == 'incident.delegate':
-            status = status_code.OPEN
-            user = message['data']['incident']['assigned_to_user']['name']
-            text = 'Incident %s reassigned due to escalation to %s' % (incident_url, user)
-        else:
-            status = status_code.UNKNOWN
-            text = message['type']
-            LOG.warn('Unknown PagerDuty message type: %s', message)
-
-        LOG.info('PagerDuty webhook %s change status to %s', message['type'], status)
-
-        alert = db.update_status(id=id, status=status, text=text)
-        db.tag_alert(id=id, tags='incident=#%s' % incident_number)
-
-        LOG.error('returned status %s', alert.status)
-        LOG.error('current status %s', db.get_alert(id=id).status)
-
-        # Forward alert to notify topic and logger queue
-        if alert:
-            alert.origin = 'pagerduty/webhook'
-            for plugin in plugins:
-                try:
-                    plugin.post_receive(alert)
-                except Exception as e:
-                    LOG.warning('Error while running post-receive plug-in: %s', e)
-
-    return jsonify(status="ok")
-
 
 # Return a list of heartbeats
 @app.route('/heartbeats', methods=['OPTIONS', 'GET'])
